#include <xc.h>

// Red LEDs -> RC1 in PWM mode
// Speaker -> RC2 in PWM mode
// I2C -> RC3/4
// Green LEDs -> RC5 in PWM mode

// Button 1 (Up) -> RB5
// Button 2 (Right) -> RB4
// Button 3 (Left) -> RB3
// Button 4 (Down) -> RB2
// Button 5 (B) -> RB1
// Button 6 (A) -> RB0

void hal_init(void)
{
    // Hardware initialization part 0: Oscillator configuration
    OSCTUNEbits.INTSRC = 1; // select internal HF oscillator
    OSCCONbits.IRCF = 7; // select 16 MHz
    OSCTUNEbits.PLLEN = 1; // enable PLL
    
    // Hardware initialization part 1: I/O configuration
    LATA = 0x00; // port A is not connected anywhere, so we set all pins low...
    TRISA = 0x00; // ... and to output to save power
    
    LATB = 0x00; // port B is mainly used for the input buttons, so no output
    TRISB = 0x3F; // RB0-5 set to input
    WPUB = 0x3F; // enable the pull up resistors for RB0-5...
    INTCON2bits.RBPU = 0; // ... and enable pull ups in general
    
    LATC = 0b00100010; // LEDs are active low, so their pins should be high
    TRISC = 0x00; // there are no inputs in port C
    
    // Hardware initialization part 2: Timer configuration
    // Timer 0 for programme flow
    T0CONbits.TMR0ON = 1; // start timer
    T0CONbits.T08BIT = 0; // 16 bit mode
    T0CONbits.T0CS = 0; // internal clock = 16 MHz / prescaler
    T0CONbits.PSA = 0; // prescaler on
    T0CONbits.T0PS = 7; // prescaler set to 256 => clock input is 62.5 kHz
    INTCONbits.TMR0IE = 1; // enable Timer 0 interrupt
    // Timer 2 for PWM (speaker)
    // Timer 4 for PWM (LED red)
    // Timer 5 for PWM (LED green)
    
    // Hardware initialization part 3: Interrupts
    RCONbits.IPEN = 0; // switch off interrupt priorities
    INTCONbits.GIE = 1; // switch on interrupts
    INTCONbits.PEIE = 1; // switch on peripheral interrupts
}